@@ -18,7 +18,7 @@ class SQSClient(Boto3Client):
         """
         msg_body = {
             'projectId': project_id,
-            'pageId': document_id
+            'documentId': document_id
         }
         self.send_message(
             QueueUrl="https://sqs.eu-west-3.amazonaws.com/749868801319/preprocess-queue",
@@ -46,7 +46,7 @@ class SQSClient(Boto3Client):
             QueueUrl="https://sqs.eu-west-3.amazonaws.com/749868801319/preprocess-queue",
             AttributeNames=['ApproximateNumberOfMessages']
         )['Attributes']['ApproximateNumberOfMessages']
-        return num_msgs == 0
+        return int(num_msgs) == 0
         
     def empty_ocr(self):
         """
@@ -55,4 +55,4 @@ class SQSClient(Boto3Client):
             QueueUrl="https://sqs.eu-west-3.amazonaws.com/749868801319/ocr-queue",
             AttributeNames=['ApproximateNumberOfMessages']
         )['Attributes']['ApproximateNumberOfMessages']
-        return num_msgs == 0
\ No newline at end of file
+        return int(num_msgs) == 0
\ No newline at end of file
